@@ -172,4 +172,22 @@ pub fn contains<P: AsRef<Path>, S: AsRef<str>>(src:P, pat:S) -> Option<bool> {
 
     }
 
+}
+
+pub fn merge<P: AsRef<Path>>(src1:P, src2:P) -> bool {
+
+    match self::read_text(src2) {
+
+        Some(s) => match self::write_text(src1, s, false) {
+
+            Some(_) => true,
+
+            None => false,
+
+        }
+
+        None => false,
+
+    }
+
 }
\ No newline at end of file
